gparted r970 - in trunk: . include src



Author: gedakc
Date: Tue Nov 18 23:58:17 2008
New Revision: 970
URL: http://svn.gnome.org/viewvc/gparted?rev=970&view=rev

Log:
Fixed incorrect spelling of filesystem and mountpoint

Modified:
   trunk/ChangeLog
   trunk/include/Partition.h
   trunk/include/Utils.h
   trunk/src/Dialog_Partition_Info.cc
   trunk/src/Dialog_Partition_New.cc
   trunk/src/Dialog_Partition_Resize_Move.cc
   trunk/src/GParted_Core.cc
   trunk/src/OperationCheck.cc
   trunk/src/TreeView_Detail.cc
   trunk/src/Win_GParted.cc
   trunk/src/ext2.cc
   trunk/src/ext3.cc
   trunk/src/fat16.cc
   trunk/src/fat32.cc
   trunk/src/jfs.cc
   trunk/src/linux_swap.cc
   trunk/src/ntfs.cc
   trunk/src/reiserfs.cc
   trunk/src/xfs.cc

Modified: trunk/include/Partition.h
==============================================================================
--- trunk/include/Partition.h	(original)
+++ trunk/include/Partition.h	Tue Nov 18 23:58:17 2008
@@ -43,7 +43,7 @@
 	STAT_FORMATTED	=	3
 };
 
-//FIXME: we should make a difference between partition- and filesystemsize. 
+//FIXME: we should make a difference between partition- and file system size. 
 //especially in the core this can make a difference when giving detailed feedback. With new cairosupport in gtkmm
 //it's even possible to make stuff like this visible in the GUI in a nice and clear way
 class Partition

Modified: trunk/include/Utils.h
==============================================================================
--- trunk/include/Utils.h	(original)
+++ trunk/include/Utils.h	Tue Nov 18 23:58:17 2008
@@ -79,7 +79,7 @@
 	UNIT_TIB	= 5
 } ;
 
-//struct to store filesysteminformation
+//struct to store file system information
 struct FS
 {
 	enum Support

Modified: trunk/src/Dialog_Partition_Info.cc
==============================================================================
--- trunk/src/Dialog_Partition_Info.cc	(original)
+++ trunk/src/Dialog_Partition_Info.cc	Tue Nov 18 23:58:17 2008
@@ -148,7 +148,7 @@
 	this ->get_vbox() ->pack_start( *table, Gtk::PACK_SHRINK ) ;
 	
 	//filesystem
-	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("Filesystem:") ) + "</b>" ),
+	table ->attach( * Utils::mk_label( "<b>" + Glib::ustring( _("File System:") ) + "</b>" ),
 			0, 1,
 			top, bottom,
 			Gtk::FILL ) ;

Modified: trunk/src/Dialog_Partition_New.cc
==============================================================================
--- trunk/src/Dialog_Partition_Resize_Move.cc	(original)
+++ trunk/src/Dialog_Partition_Resize_Move.cc	Tue Nov 18 23:58:17 2008
@@ -90,7 +90,7 @@
 
 	Sector previous, next ;
 	previous = next = 0 ;
-	//also check the partitions filesystem ( if this is a 'resize-only' then previous should be 0 )	
+	//also check the partitions file system ( if this is a 'resize-only' then previous should be 0 )	
 	if ( t >= 1 && partitions[t -1].type == GParted::TYPE_UNALLOCATED && ! this ->fixed_start )
 	{ 
 		previous = partitions[t -1] .get_length() ;
@@ -116,7 +116,7 @@
 	//set MIN
 	if ( fs .shrink )
 	{
-		//since some filesystems have lower limits we need to check for this
+		//since some file systems have lower limits we need to check for this
 		if ( selected_partition .sectors_used > fs .MIN )
 			fs .MIN = selected_partition .sectors_used ;
 

Modified: trunk/src/GParted_Core.cc
==============================================================================
--- trunk/src/ext2.cc	(original)
+++ trunk/src/ext2.cc	Tue Nov 18 23:58:17 2008
@@ -43,7 +43,7 @@
 	{
 		fs .grow = FS::EXTERNAL ;
 		
-		if ( fs .read ) //needed to determine a min filesystemsize..
+		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = FS::EXTERNAL ;
 	}
 
@@ -131,7 +131,7 @@
 {
 	exit_status = execute_command( "e2fsck -f -y -v " + partition .get_path(), operationdetail ) ;
 	
-	//exitstatus 256 isn't documented, but it's returned when the 'FILESYSTEM IS MODIFIED'
+	//exitstatus 256 isn't documented, but it's returned when the 'FILE SYSTEM IS MODIFIED'
 	//this is quite normal (especially after a copy) so we let the function return true...
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 2 || exit_status == 256 ) ;
 }

Modified: trunk/src/ext3.cc
==============================================================================
--- trunk/src/ext3.cc	(original)
+++ trunk/src/ext3.cc	Tue Nov 18 23:58:17 2008
@@ -44,7 +44,7 @@
 	{
 		fs .grow = GParted::FS::EXTERNAL ;
 		
-		if ( fs .read ) //needed to determine a min filesystemsize..
+		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = GParted::FS::EXTERNAL ;
 	}
 
@@ -132,7 +132,7 @@
 {
 	exit_status = execute_command( "e2fsck -f -y -v " + partition .get_path(), operationdetail ) ;
 
-	//exitstatus 256 isn't documented, but it's returned when the 'FILESYSTEM IS MODIFIED'
+	//exitstatus 256 isn't documented, but it's returned when the 'FILE SYSTEM IS MODIFIED'
 	//this is quite normal (especially after a copy) so we let the function return true...
 	return ( exit_status == 0 || exit_status == 1 || exit_status == 2 || exit_status == 256 ) ;
 }

Modified: trunk/src/fat16.cc
==============================================================================
--- trunk/src/fat16.cc	(original)
+++ trunk/src/fat16.cc	Tue Nov 18 23:58:17 2008
@@ -33,7 +33,7 @@
 	FS fs ;
 	fs .filesystem = GParted::FS_FAT16 ;
 		
-	//find out if we can create fat16 filesystems
+	//find out if we can create fat16 file systems
 	if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
 	

Modified: trunk/src/fat32.cc
==============================================================================
--- trunk/src/fat32.cc	(original)
+++ trunk/src/fat32.cc	Tue Nov 18 23:58:17 2008
@@ -33,7 +33,7 @@
 	FS fs ;
 	fs .filesystem = GParted::FS_FAT32 ;
 		
-	//find out if we can create fat32 filesystems
+	//find out if we can create fat32 file systems
 	if ( ! Glib::find_program_in_path( "mkdosfs" ) .empty() )
 		fs .create = GParted::FS::EXTERNAL ;
 	
@@ -62,7 +62,7 @@
 
 void fat32::set_used_sectors( Partition & partition ) 
 {
-	//FIXME: i've encoutered a readonly fat32 filesystem.. this won't work with the -a ... best check also without the -a
+	//FIXME: i've encoutered a readonly fat32 file system.. this won't work with the -a ... best check also without the -a
 	exit_status = Utils::execute_command( "dosfsck -a -v " + partition .get_path(), output, error, true ) ;
 	if ( exit_status == 0 || exit_status == 1 || exit_status == 256 )
 	{

Modified: trunk/src/jfs.cc
==============================================================================
--- trunk/src/jfs.cc	(original)
+++ trunk/src/jfs.cc	Tue Nov 18 23:58:17 2008
@@ -134,10 +134,10 @@
 {
 	bool return_value = false ;
 	Glib::ustring error ;
-	Glib::ustring TEMP_MP = Glib::get_tmp_dir() + "/gparted_tmp_jfs_mountpoint" ;
+	Glib::ustring TEMP_MP = Glib::get_tmp_dir() + "/gparted_tmp_jfs_mount_point" ;
 	
-	//create mountpoint...
-	operationdetail .add_child( OperationDetail( String::ucompose( _("create temporary mountpoint (%1)"), TEMP_MP ) ) ) ;
+	//create mount point...
+	operationdetail .add_child( OperationDetail( String::ucompose( _("create temporary mount point (%1)"), TEMP_MP ) ) ) ;
 	if ( ! mkdir( TEMP_MP .c_str(), 0 ) )
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -151,7 +151,7 @@
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 			
-			//remount the partition to resize the filesystem
+			//remount the partition to resize the file system
 			operationdetail .add_child(
 				OperationDetail( String::ucompose( _("remount %1 on %2 with the 'resize' flag enabled"),
 								   partition_new .get_path(),
@@ -189,9 +189,9 @@
 			operationdetail .get_last_child() .set_status( STATUS_ERROR ) ;
 		}
 		
-		//remove the mountpoint..
+		//remove the mount point..
 		operationdetail .add_child(
-			OperationDetail( String::ucompose( _("remove temporary mountpoint (%1)"), TEMP_MP ) ) ) ;
+			OperationDetail( String::ucompose( _("remove temporary mount point (%1)"), TEMP_MP ) ) ) ;
 		if ( ! rmdir( TEMP_MP .c_str() ) )
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;

Modified: trunk/src/linux_swap.cc
==============================================================================
--- trunk/src/ntfs.cc	(original)
+++ trunk/src/ntfs.cc	Tue Nov 18 23:58:17 2008
@@ -45,7 +45,7 @@
 	{
 		fs .grow = GParted::FS::EXTERNAL ;
 		
-		if ( fs .read ) //needed to determine a min filesystemsize..
+		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = GParted::FS::EXTERNAL ;
 	}
 	

Modified: trunk/src/reiserfs.cc
==============================================================================
--- trunk/src/Dialog_Partition_New.cc	(original)
+++ trunk/src/Dialog_Partition_New.cc	Tue Nov 18 23:58:17 2008
@@ -88,8 +88,8 @@
 		sigc::bind<bool>( sigc::mem_fun( *this, &Dialog_Partition_New::optionmenu_changed ), true ) );
 	table_create .attach( optionmenu_type, 1, 2, 0, 1, Gtk::FILL );
 	
-	//filesystems to choose from 
-	table_create .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("Filesystem:") ) + "\t" ),
+	//file systems to choose from 
+	table_create .attach( * Utils::mk_label( static_cast<Glib::ustring>( _("File System:") ) + "\t" ),
 			     0, 1, 1, 2,
 			     Gtk::FILL );
 	
@@ -118,7 +118,7 @@
 	TOTAL_MB = Utils::round( Utils::sector_to_unit( this ->selected_partition .get_length(), GParted::UNIT_MIB ) ) ;
 	MB_PER_PIXEL = TOTAL_MB / 500.00 ;
 	
 	//set first enabled filesystem
 	optionmenu_filesystem .set_history( first_creatable_fs ) ;
 	optionmenu_changed( false ) ;
 	
@@ -268,7 +268,7 @@
 
 void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted ) 
 {
 	//fill the filesystem menu with the filesystems (except for extended) 
 	for ( unsigned int t = 0 ; t < FILESYSTEMS .size( ) -1 ; t++ ) 
 	{
 		menu_filesystem .items() .push_back( 
@@ -281,7 +281,7 @@
 	//unformatted is always available
 	menu_filesystem .items() .back() .set_sensitive( true ) ;
 	
 	//find and set first enabled filesystem
 	for ( unsigned int t = 0 ; t < menu_filesystem .items() .size() ; t++ )
 		if ( menu_filesystem .items()[ t ] .sensitive() )
 		{
@@ -118,7 +118,7 @@
 	MB_PER_PIXEL = TOTAL_MB / 500.00 ;
 	
-	//set first enabled filesystem
+	//set first enabled file system
 	optionmenu_filesystem .set_history( first_creatable_fs ) ;
 	optionmenu_changed( false ) ;
@@ -268,7 +268,7 @@
 void Dialog_Partition_New::Build_Filesystems_Menu( bool only_unformatted ) 
 {
-	//fill the filesystem menu with the filesystems (except for extended) 
+	//fill the file system menu with the file systems (except for extended) 
 	for ( unsigned int t = 0 ; t < FILESYSTEMS .size( ) -1 ; t++ ) 
 	{
@@ -281,7 +281,7 @@
 	menu_filesystem .items() .back() .set_sensitive( true ) ;
 	
-	//find and set first enabled filesystem
+	//find and set first enabled file system
 	for ( unsigned int t = 0 ; t < menu_filesystem .items() .size() ; t++ )
 		if ( menu_filesystem .items()[ t ] .sensitive() )

Modified: trunk/src/Dialog_Partition_Resize_Move.cc
==============================================================================
--- trunk/src/GParted_Core.cc	(original)
+++ trunk/src/GParted_Core.cc	Tue Nov 18 23:58:17 2008
@@ -74,7 +74,7 @@
 	std::cout << "libparted : " << ped_get_version() << std::endl ;
 	std::cout << "======================" << std::endl ;
 
-	//initialize filesystemlist
+	//initialize file system list
 	find_supported_filesystems() ;
 }
 
@@ -121,7 +121,7 @@
 	xfs fs_xfs;
 	FILESYSTEMS .push_back( fs_xfs .get_filesystem_support() ) ;
 	
 	//unknown filesystem (default when no match is found)
 	FS fs ; fs .filesystem = GParted::FS_UNKNOWN ;
 	FILESYSTEMS .push_back( fs ) ;
 }
@@ -592,7 +592,7 @@
 	read_mountpoints_from_file( "/etc/mtab", mount_info ) ;
 	read_mountpoints_from_file( "/etc/fstab", fstab_info ) ;
 	
 	//sort the mountpoints and remove duplicates.. (no need to do this for fstab_info)
 	for ( iter_mp = mount_info .begin() ; iter_mp != mount_info .end() ; ++iter_mp )
 	{
 		std::sort( iter_mp ->second .begin(), iter_mp ->second .end() ) ;
@@ -648,7 +648,7 @@
 			{
 				line = mountpoint ;
 				
 				//see if mountpoint contains spaces and deal with it
 				index = line .find( "\\040" ) ;
 				if ( index < line .length() )
 					line .replace( index, 4, " " ) ;
@@ -775,7 +775,7 @@
 
 GParted::FILESYSTEM GParted_Core::get_filesystem() 
 {
 	//standard libparted filesystems..
 	if ( lp_partition && lp_partition ->fs_type )
 	{
 		if ( Glib::ustring( lp_partition ->fs_type ->name ) == "extended" )
@@ -807,7 +807,7 @@
 	}
 	
 	
 	//other filesystems libparted couldn't detect (i've send patches for these filesystems to the parted guys)
 	char buf[512] ;
 
 	ped_device_open( lp_device );
@@ -819,14 +819,14 @@
 	if ( Glib::ustring( buf ) == "ReIsEr4" )
 		return GParted::FS_REISER4 ;		
 		
-	//no filesystem found....
-	temp = _( "Unable to detect filesystem! Possible reasons are:" ) ;
+	//no file system found....
+	temp = _( "Unable to detect file system! Possible reasons are:" ) ;
 	temp += "\n-"; 
-	temp += _( "The filesystem is damaged" ) ;
+	temp += _( "The file system is damaged" ) ;
 	temp += "\n-" ; 
-	temp += _( "The filesystem is unknown to GParted" ) ;
+	temp += _( "The file system is unknown to GParted" ) ;
 	temp += "\n-"; 
-	temp += _( "There is no filesystem available (unformatted)" ) ; 
+	temp += _( "There is no file system available (unformatted)" ) ; 
 	
 	partition_temp .messages .push_back( temp ) ;
 	
@@ -922,7 +922,7 @@
 				}
 
 				if ( partitions[ t ] .get_mountpoints() .empty() )
-					partitions[ t ] .messages .push_back( _("Unable to find mountpoint") ) ;
+					partitions[ t ] .messages .push_back( _("Unable to find mount point") ) ;
 			}
 			else
 			{
@@ -940,7 +940,7 @@
 {
 	struct statvfs sfs ; 
 	
-	temp = _("Unable to read the contents of this filesystem!") ;
+	temp = _("Unable to read the contents of this file system!") ;
 	temp += "\n" ;
 	temp += _("Because of this some operations may be unavailable.") ;
 	
@@ -1149,9 +1149,9 @@
 	
 bool GParted_Core::create_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
 	/*TO TRANSLATORS: looks like create new ext3 filesystem */ 
 	operationdetail .add_child( OperationDetail( String::ucompose(
-							_("create new %1 filesystem"),
+							_("create new %1 file system"),
 							Utils::get_filesystem_string( partition .filesystem ) ) ) ) ;
 	
 	bool succes = false ;
@@ -1176,7 +1176,7 @@
 
 bool GParted_Core::format( const Partition & partition, OperationDetail & operationdetail )
 {	
 	//remove all filesystem signatures...
 	erase_filesystem_signatures( partition ) ;
 
 	return set_partition_type( partition, operationdetail ) && create_filesystem( partition, operationdetail ) ;
@@ -1297,7 +1297,7 @@
 	if ( check_repair_filesystem( partition_old, operationdetail ) )
 	{
 		//NOTE: logical partitions are preceeded by metadata. To prevent this metadata from being
 		//overwritten we move the partition first and only then the filesystem when moving to the left.
 		//(maybe i should do some reading on how non-msdos disklabels deal with metadata....)
 		if ( partition_new .sector_start < partition_old .sector_start )
 		{
@@ -1334,14 +1334,14 @@
 				    OperationDetail & operationdetail ) 
 {
 	if ( partition_new .sector_start < partition_old .sector_start )
-		operationdetail .add_child( OperationDetail( _("move filesystem to the left") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system to the left") ) ) ;
 	else if ( partition_new .sector_start > partition_old .sector_start )
-		operationdetail .add_child( OperationDetail( _("move filesystem to the right") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system to the right") ) ) ;
 	else
 	{
-		operationdetail .add_child( OperationDetail( _("move filesystem") ) ) ;
+		operationdetail .add_child( OperationDetail( _("move file system") ) ) ;
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("new and old filesystem have the same position -- skipping this operation"),
+			OperationDetail( _("new and old file system have the same position -- skipping this operation"),
 					 STATUS_NONE,
 					 FONT_ITALIC ) ) ;
 
@@ -1462,7 +1462,7 @@
 		if ( ! check_repair_filesystem( partition_new, operationdetail ) )
 			succes = false ;
 
 		//expand filesystem to fit exactly in partition
 		if ( ! maximize_filesystem( partition_new, operationdetail ) )
 			succes = false ;
 			
@@ -1639,17 +1639,17 @@
 	{
 		if ( partition_new .get_length() < partition_old .get_length() )
 		{
-			operationdetail .add_child( OperationDetail( _("shrink filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("shrink file system") ) ) ;
 			action = get_fs( partition_old .filesystem ) .shrink ;
 		}
 		else if ( partition_new .get_length() > partition_old .get_length() )
-			operationdetail .add_child( OperationDetail( _("grow filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("grow file system") ) ) ;
 		else
 		{
-			operationdetail .add_child( OperationDetail( _("resize filesystem") ) ) ;
+			operationdetail .add_child( OperationDetail( _("resize file system") ) ) ;
 			operationdetail .get_last_child() .add_child( 
 				OperationDetail( 
-					_("new and old filesystem have the same size -- skipping this operation"),
+					_("new and old file system have the same size -- skipping this operation"),
 					STATUS_NONE,
 					FONT_ITALIC ) ) ;
 		
@@ -1684,12 +1684,12 @@
 	
 bool GParted_Core::maximize_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
-	operationdetail .add_child( OperationDetail( _("grow filesystem to fill the partition") ) ) ;
+	operationdetail .add_child( OperationDetail( _("grow file system to fill the partition") ) ) ;
 
 	if ( get_fs( partition .filesystem ) .grow == GParted::FS::NONE )
 	{
 		operationdetail .get_last_child() .add_child( 
-			OperationDetail( _("growing is not available for this filesystem"),
+			OperationDetail( _("growing is not available for this file system"),
 					  STATUS_NONE,
 					  FONT_ITALIC ) ) ;
 
@@ -1722,7 +1722,7 @@
 		if ( succes && set_partition_type( partition_dst, operationdetail ) )
 		{
 			operationdetail .add_child( OperationDetail( 
-				String::ucompose( _("copy filesystem of %1 to %2"),
+				String::ucompose( _("copy file system of %1 to %2"),
 						  partition_src .get_path(),
 						  partition_dst .get_path() ) ) ) ;
 						
@@ -1901,7 +1901,7 @@
 	{
 		operationdetail .add_child( OperationDetail( _("rollback last transaction") ) ) ;
 
 		//find out exactly which part of the filesystem was copied (and to where it was copied)..
 		Partition temp_src = partition_src ;
 		Partition temp_dst = partition_dst ;
 
@@ -1926,7 +1926,7 @@
 bool GParted_Core::check_repair_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
 	operationdetail .add_child( OperationDetail( 
-				String::ucompose( _("check filesystem on %1 for errors and (if possible) fix them"),
+				String::ucompose( _("check file system on %1 for errors and (if possible) fix them"),
 						  partition .get_path() ) ) ) ;
 	
 	bool succes = false ;
@@ -1934,7 +1934,7 @@
 	{
 		case GParted::FS::NONE:
 			operationdetail .get_last_child() .add_child(
-				OperationDetail( _("checking is not available for this filesystem"),
+				OperationDetail( _("checking is not available for this file system"),
 						 STATUS_NONE,
 						 FONT_ITALIC ) ) ;
 
@@ -2320,7 +2320,7 @@
 
 		if ( lp_partition && ped_file_system_clobber( & lp_partition ->geom ) )
 		{
 			//filesystems not yet supported by libparted
 			if ( ped_device_open( lp_device ) )
 			{
 				//reiser4 stores "ReIsEr4" at sector 128
@@ -2344,7 +2344,7 @@
 	if ( partition .filesystem == FS_NTFS )
 	{
 		operationdetail .add_child( OperationDetail( 
-			String::ucompose( _("updating boot sector of %1 filesystem on %2"),
+			String::ucompose( _("updating boot sector of %1 file system on %2"),
 					  Utils::get_filesystem_string( partition .filesystem ),
 					  partition .get_path() ) ) ) ;
 
@@ -121,7 +121,7 @@
 	FILESYSTEMS .push_back( fs_xfs .get_filesystem_support() ) ;
 	
-	//unknown filesystem (default when no match is found)
+	//unknown file system (default when no match is found)
 	FS fs ; fs .filesystem = GParted::FS_UNKNOWN ;
 	FILESYSTEMS .push_back( fs ) ;
@@ -592,7 +592,7 @@
 	read_mountpoints_from_file( "/etc/fstab", fstab_info ) ;
 	
-	//sort the mountpoints and remove duplicates.. (no need to do this for fstab_info)
+	//sort the mount points and remove duplicates.. (no need to do this for fstab_info)
 	for ( iter_mp = mount_info .begin() ; iter_mp != mount_info .end() ; ++iter_mp )
 	{
@@ -648,7 +648,7 @@
 				line = mountpoint ;
 				
-				//see if mountpoint contains spaces and deal with it
+				//see if mount point contains spaces and deal with it
 				index = line .find( "\\040" ) ;
 				if ( index < line .length() )
@@ -775,7 +775,7 @@
 GParted::FILESYSTEM GParted_Core::get_filesystem() 
 {
-	//standard libparted filesystems..
+	//standard libparted file systems..
 	if ( lp_partition && lp_partition ->fs_type )
 	{
@@ -807,7 +807,7 @@
 	
 	
-	//other filesystems libparted couldn't detect (i've send patches for these filesystems to the parted guys)
+	//other file systems libparted couldn't detect (i've send patches for these file systems to the parted guys)
 	char buf[512] ;
 
@@ -1149,9 +1149,9 @@
 bool GParted_Core::create_filesystem( const Partition & partition, OperationDetail & operationdetail ) 
 {
-	/*TO TRANSLATORS: looks like create new ext3 filesystem */ 
+	/*TO TRANSLATORS: looks like create new ext3 file system */ 
 	operationdetail .add_child( OperationDetail( String::ucompose(
@@ -1176,7 +1176,7 @@
 bool GParted_Core::format( const Partition & partition, OperationDetail & operationdetail )
 {	
-	//remove all filesystem signatures...
+	//remove all file system signatures...
 	erase_filesystem_signatures( partition ) ;
 
@@ -1297,7 +1297,7 @@
 	{
 		//NOTE: logical partitions are preceeded by metadata. To prevent this metadata from being
-		//overwritten we move the partition first and only then the filesystem when moving to the left.
+		//overwritten we move the partition first and only then the file system when moving to the left.
 		//(maybe i should do some reading on how non-msdos disklabels deal with metadata....)
 		if ( partition_new .sector_start < partition_old .sector_start )
@@ -1462,7 +1462,7 @@
 			succes = false ;
 
-		//expand filesystem to fit exactly in partition
+		//expand file system to fit exactly in partition
 		if ( ! maximize_filesystem( partition_new, operationdetail ) )
 			succes = false ;
@@ -1901,7 +1901,7 @@
 		operationdetail .add_child( OperationDetail( _("rollback last transaction") ) ) ;
 
-		//find out exactly which part of the filesystem was copied (and to where it was copied)..
+		//find out exactly which part of the file system was copied (and to where it was copied)..
 		Partition temp_src = partition_src ;
 		Partition temp_dst = partition_dst ;
@@ -2320,7 +2320,7 @@
 		if ( lp_partition && ped_file_system_clobber( & lp_partition ->geom ) )
 		{
-			//filesystems not yet supported by libparted
+			//file systems not yet supported by libparted
 			if ( ped_device_open( lp_device ) )
 			{

Modified: trunk/src/OperationCheck.cc
==============================================================================
--- trunk/src/OperationCheck.cc	(original)
+++ trunk/src/OperationCheck.cc	Tue Nov 18 23:58:17 2008
@@ -34,8 +34,8 @@
 
 void OperationCheck::create_description() 
 {
-	/*TO TRANSLATORS: looks like  Check and repair filesystem (ext3) on /dev/hda4 */
-	description = String::ucompose( _("Check and repair filesystem (%1) on %2"),
+	/*TO TRANSLATORS: looks like  Check and repair file system (ext3) on /dev/hda4 */
+	description = String::ucompose( _("Check and repair file system (%1) on %2"),
 					Utils::get_filesystem_string( partition_original .filesystem ),	
 					partition_original .get_path() ) ;
 }

Modified: trunk/src/TreeView_Detail.cc
==============================================================================
--- trunk/src/TreeView_Detail.cc	(original)
+++ trunk/src/TreeView_Detail.cc	Tue Nov 18 23:58:17 2008
@@ -32,8 +32,8 @@
 
 	//append columns
 	append_column( _("Partition"), treeview_detail_columns .path );
-	append_column( _("Filesystem"), treeview_detail_columns .color );
-	append_column( _("Mountpoint"), treeview_detail_columns .mountpoint );
+	append_column( _("File System"), treeview_detail_columns .color );
+	append_column( _("Mount Point"), treeview_detail_columns .mountpoint );
 	append_column( _("Label"), treeview_detail_columns .label );
 	append_column( _("Size"), treeview_detail_columns .size );
 	append_column( _("Used"), treeview_detail_columns .used );
@@ -51,11 +51,11 @@
 	get_column( 0 ) ->add_attribute( cell_renderer_text ->property_foreground(), 
 					 treeview_detail_columns .text_color );
 	
-	//FILESYSTEM
-	//filesystem text
+	//FILE SYSTEM
+	//file system text
 	get_column( 1 ) ->pack_start( treeview_detail_columns .filesystem, true );
 	
 	//colored text in Filesystem column 
 	std::vector<Gtk::CellRenderer*> renderers = get_column( 1 ) ->get_cell_renderers() ;
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers .back() ) ;
 	get_column( 1 ) ->add_attribute( cell_renderer_text ->property_foreground(),
@@ -65,8 +65,8 @@
 	get_column( 1 ) ->get_first_cell_renderer() ->property_xalign() = Gtk::ALIGN_LEFT ;
 	cell_renderer_text ->property_xalign() = Gtk::ALIGN_LEFT ;
 	
 	//MOUNTPOINT
 	//colored text in mountpoint column 
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( get_column( 2 ) ->get_first_cell_renderer() );
 	get_column( 2 ) ->add_attribute( cell_renderer_text ->property_foreground(), 
 					 treeview_detail_columns .mount_text_color );
@@ -179,7 +179,7 @@
 	treerow[ treeview_detail_columns .filesystem ] = 
 		Utils::get_filesystem_string( partition .filesystem ) ;
 	
-	//mountpoint
+	//mount point
 	treerow[ treeview_detail_columns .mountpoint ] = Glib::build_path( ", ", partition .get_mountpoints() ) ;
 
 	//label
@@ -51,11 +51,11 @@
 	get_column( 1 ) ->pack_start( treeview_detail_columns .filesystem, true );
 	
-	//colored text in Filesystem column 
+	//colored text in File System column 
 	std::vector<Gtk::CellRenderer*> renderers = get_column( 1 ) ->get_cell_renderers() ;
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( renderers .back() ) ;
@@ -65,8 +65,8 @@
 	cell_renderer_text ->property_xalign() = Gtk::ALIGN_LEFT ;
 	
-	//MOUNTPOINT
-	//colored text in mountpoint column 
+	//MOUNT POINT
+	//colored text in mount point column 
 	cell_renderer_text = dynamic_cast<Gtk::CellRendererText*>( get_column( 2 ) ->get_first_cell_renderer() );
 	get_column( 2 ) ->add_attribute( cell_renderer_text ->property_foreground(), 

Modified: trunk/src/Win_GParted.cc
==============================================================================
--- trunk/src/Win_GParted.cc	(original)
+++ trunk/src/Win_GParted.cc	Tue Nov 18 23:58:17 2008
@@ -315,7 +315,7 @@
 	index++ ;
 	
 	image = manage( new Gtk::Image( Gtk::Stock::CONVERT, Gtk::ICON_SIZE_MENU ) );
 	/*TO TRANSLATORS: menuitem which holds a submenu with filesystems.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::ImageMenuElem( _("_Format to"),
 							  *image,
@@ -330,7 +330,7 @@
 						     sigc::mem_fun( *this, &Win_GParted::toggle_swap_mount_state ) ) );
 	MENU_TOGGLE_MOUNT_SWAP = index++ ;
 		
-	/*TO TRANSLATORS: menuitem which holds a submenu with mountpoints.. */
+	/*TO TRANSLATORS: menuitem which holds a submenu with mount points.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::MenuElem( _("_Mount on"), * manage( new Gtk::Menu() ) ) ) ;
 	MENU_MOUNT = index++ ;
@@ -887,7 +887,7 @@
 		     copied_partition != selected_partition )
 		     allow_paste( true ) ;
 
 		//see if we can somehow check/repair this filesystem....
 		if ( fs .check && selected_partition .status == GParted::STAT_REAL )
 			allow_check( true ) ;
 	}
@@ -1364,7 +1364,7 @@
 		{
 			Dialog_Partition_Copy dialog( gparted_core .get_fs( copied_partition .filesystem ),
 						      devices[ current_device ] .cylsize ) ;
-			//we don't need the messages/mountpoints of the source partition.
+			//we don't need the messages/mount points of the source partition.
 			copied_partition .messages .clear() ;
 			copied_partition .clear_mountpoints() ;
 			dialog .Set_Data( selected_partition, copied_partition ) ;
@@ -1545,7 +1545,7 @@
 	     fs .MAX && selected_partition .get_length() > fs .MAX ) 
 	{
 		Gtk::MessageDialog dialog( *this,
-					   String::ucompose( _("Cannot format this filesystem to %1."),
+					   String::ucompose( _("Cannot format this file system to %1."),
 						   	     Utils::get_filesystem_string( new_fs ) ) ,
 					   false,
 					   Gtk::MESSAGE_ERROR,
@@ -1554,12 +1554,12 @@
 
 		if ( selected_partition .get_length() < fs .MIN )
 			dialog .set_secondary_text( String::ucompose( 
-						_( "A %1 filesystem requires a partition of at least %2."),
+						_( "A %1 file system requires a partition of at least %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MIN ) ) );
 		else
 			dialog .set_secondary_text( String::ucompose( 
-						_( "A partition with a %1 filesystem has a maximum size of %2."),
+						_( "A partition with a %1 file system has a maximum size of %2."),
 						Utils::get_filesystem_string( new_fs ),
 						Utils::format_size( fs .MAX ) ) );
 		
@@ -1582,7 +1582,7 @@
 	part_temp .status = GParted::STAT_FORMATTED ;
 	
 	//if selected_partition is NEW we simply remove the NEW operation from the list and
 	//add it again with the new filesystem
 	if ( selected_partition .status == GParted::STAT_NEW )
 	{
 		//remove operation which creates this partition
@@ -1644,9 +1644,9 @@
 	if ( *succes && failed_mountpoints .size() )
 	{
 		*succes = false ;
-		*error = _("The partition could not be unmounted from the following mountpoints:") ;
+		*error = _("The partition could not be unmounted from the following mount points:") ;
 		*error += "\n\n<i>" + Glib::build_path( "\n", failed_mountpoints ) + "</i>\n\n" ;
-		*error +=  _("Most likely other partitions are also mounted on these mountpoints. You are advised to unmount them manually.") ;
+		*error +=  _("Most likely other partitions are also mounted on these mount points. You are advised to unmount them manually.") ;
 	}
 	else
 		*error = "<i>" + Glib::build_path( "\n", errors ) + "</i>" ;
@@ -315,7 +315,7 @@
 	
 	image = manage( new Gtk::Image( Gtk::Stock::CONVERT, Gtk::ICON_SIZE_MENU ) );
-	/*TO TRANSLATORS: menuitem which holds a submenu with filesystems.. */
+	/*TO TRANSLATORS: menuitem which holds a submenu with file systems.. */
 	menu_partition .items() .push_back(
 			Gtk::Menu_Helpers::ImageMenuElem( _("_Format to"),
@@ -887,7 +887,7 @@
 		     allow_paste( true ) ;
 
-		//see if we can somehow check/repair this filesystem....
+		//see if we can somehow check/repair this file system....
 		if ( fs .check && selected_partition .status == GParted::STAT_REAL )
 			allow_check( true ) ;
@@ -1582,7 +1582,7 @@
 	
 	//if selected_partition is NEW we simply remove the NEW operation from the list and
-	//add it again with the new filesystem
+	//add it again with the new file system
 	if ( selected_partition .status == GParted::STAT_NEW )
 	{

Modified: trunk/src/ext2.cc
==============================================================================
--- trunk/src/linux_swap.cc	(original)
+++ trunk/src/linux_swap.cc	Tue Nov 18 23:58:17 2008
@@ -74,9 +74,9 @@
 
 bool linux_swap::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
 	/*TO TRANSLATORS: looks like create new linux-swap filesystem */ 
 	operationdetail .add_child( OperationDetail( 
-		String::ucompose( _("create new %1 filesystem"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
+		String::ucompose( _("create new %1 file system"), Utils::get_filesystem_string( FS_LINUX_SWAP ) ) ) ) ;
 	if ( create( partition_new, operationdetail .get_last_child() ) ) 
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -74,9 +74,9 @@
 bool linux_swap::resize( const Partition & partition_new, OperationDetail & operationdetail, bool fill_partition )
 {
-	/*TO TRANSLATORS: looks like create new linux-swap filesystem */ 
+	/*TO TRANSLATORS: looks like create new linux-swap file system */ 
 	operationdetail .add_child( OperationDetail( 

Modified: trunk/src/ntfs.cc
==============================================================================
--- trunk/src/reiserfs.cc	(original)
+++ trunk/src/reiserfs.cc	Tue Nov 18 23:58:17 2008
@@ -46,7 +46,7 @@
 	{
 		fs .grow = GParted::FS::EXTERNAL ;
 		
-		if ( fs .read ) //needed to determine a min filesystemsize..
+		if ( fs .read ) //needed to determine a min file system size..
 			fs .shrink = GParted::FS::EXTERNAL ;
 	}
 
@@ -90,7 +90,7 @@
 
 void reiserfs::read_label( Partition & partition )
 {
 	//FIXME: i think running debugreiserfs takes a long time on filled filesystems, test for this...
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{
 		partition .label = Utils::regexp_label( output, "^label:[\t ]*(.*)$" ) ;
@@ -90,7 +90,7 @@
 void reiserfs::read_label( Partition & partition )
 {
-	//FIXME: i think running debugreiserfs takes a long time on filled filesystems, test for this...
+	//FIXME: i think running debugreiserfs takes a long time on filled file systems, test for this...
 	if ( ! Utils::execute_command( "debugreiserfs " + partition .get_path(), output, error, true ) )
 	{

Modified: trunk/src/xfs.cc
==============================================================================
--- trunk/src/xfs.cc	(original)
+++ trunk/src/xfs.cc	Tue Nov 18 23:58:17 2008
@@ -135,7 +135,7 @@
 
 bool xfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
 	//mkfs.xfs will not create filesystem if label is longer than 12 characters, hence truncation.
 	Glib::ustring label = new_partition .label ;
 	if( label .length() > 12 )
 		label = label.substr( 0, 12 ) ;
@@ -146,10 +146,10 @@
 {
 	bool return_value = false ;
 	Glib::ustring error ;
-	Glib::ustring TEMP_MP = Glib::get_tmp_dir() + "/gparted_tmp_xfs_mountpoint" ;
+	Glib::ustring TEMP_MP = Glib::get_tmp_dir() + "/gparted_tmp_xfs_mount_point" ;
 
-	//create mountpoint...
-	operationdetail .add_child( OperationDetail( String::ucompose( _("create temporary mountpoint (%1)"), TEMP_MP ) ) ) ;
+	//create mount point...
+	operationdetail .add_child( OperationDetail( String::ucompose( _("create temporary mount point (%1)"), TEMP_MP ) ) ) ;
 	if ( ! mkdir( TEMP_MP .c_str(), 0 ) )
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -163,8 +163,8 @@
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 			
-			//grow the mounted filesystem..
-			operationdetail .add_child( OperationDetail( _("grow mounted filesystem") ) ) ;
+			//grow the mounted file system..
+			operationdetail .add_child( OperationDetail( _("grow mounted file system") ) ) ;
 			
 			if ( ! execute_command ( "xfs_growfs " + TEMP_MP, operationdetail .get_last_child() ) )
 			{
@@ -196,9 +196,9 @@
 			operationdetail .get_last_child() .set_status( STATUS_ERROR ) ;
 		}
 				
-		//remove the mountpoint..
+		//remove the mount point..
 		operationdetail .add_child(
-			OperationDetail( String::ucompose( _("remove temporary mountpoint (%1)"), TEMP_MP ) ) ) ;
+			OperationDetail( String::ucompose( _("remove temporary mount point (%1)"), TEMP_MP ) ) ) ;
 		if ( ! rmdir( TEMP_MP .c_str() ) )
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -227,28 +227,28 @@
 {
 	bool return_value = false ;
 	Glib::ustring error ;
-	Glib::ustring SRC = Glib::get_tmp_dir() + "/gparted_tmp_xfs_src_mountpoint" ;
-	Glib::ustring DST = Glib::get_tmp_dir() + "/gparted_tmp_xfs_dest_mountpoint" ;
+	Glib::ustring SRC = Glib::get_tmp_dir() + "/gparted_tmp_xfs_src_mount_point" ;
+	Glib::ustring DST = Glib::get_tmp_dir() + "/gparted_tmp_xfs_dest_mount_point" ;
 	
 	//create xfs filesystem on destination..
 	/*TO TRANSLATORS: looks like Create new xfs filesystem */ 
 	operationdetail .add_child( OperationDetail( 
-		String::ucompose( _("create new %1 filesystem"), Utils::get_filesystem_string( FS_XFS ) ) ) ) ;
+		String::ucompose( _("create new %1 file system"), Utils::get_filesystem_string( FS_XFS ) ) ) ) ;
 
 	if ( create( Partition( dest_part_path ), operationdetail .get_last_child() ) )
 	{
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 		
 		//create source mountpoint...
 		operationdetail .add_child( 
-			OperationDetail( String::ucompose( _("create temporary mountpoint (%1)"), SRC ) ) ) ;
+			OperationDetail( String::ucompose( _("create temporary mount point (%1)"), SRC ) ) ) ;
 		if ( ! mkdir( SRC .c_str(), 0 ) )
 		{
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 			
 			//create destination mountpoint...
 			operationdetail .add_child(
-				OperationDetail( String::ucompose( _("create temporary mountpoint (%1)"), DST ) ) ) ;
+				OperationDetail( String::ucompose( _("create temporary mount point (%1)"), DST ) ) ) ;
 			if ( ! mkdir( DST .c_str(), 0 ) )
 			{
 				operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -271,8 +271,8 @@
 					{
 						operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 	
-						//copy filesystem..
-						operationdetail .add_child( OperationDetail( _("copy filesystem") ) ) ;
+						//copy file system..
+						operationdetail .add_child( OperationDetail( _("copy file system") ) ) ;
 						
 						if ( ! execute_command( 
 							 "xfsdump -J - " + SRC + " | xfsrestore -J - " + DST,
@@ -327,9 +327,9 @@
 					operationdetail .get_last_child() .set_status( STATUS_ERROR ) ;
 				}
 		
 				//remove destination mountpoint..
 				operationdetail .add_child(
-					OperationDetail( String::ucompose( _("remove temporary mountpoint (%1)"), DST ) ) ) ;
+					OperationDetail( String::ucompose( _("remove temporary mount point (%1)"), DST ) ) ) ;
 				if ( ! rmdir( DST .c_str() ) )
 				{
 					operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -350,9 +350,9 @@
 					OperationDetail( Glib::strerror( errno ), STATUS_NONE ) ) ;
 			}
 			
 			//remove source mountpoint..
 			operationdetail .add_child(
-				OperationDetail( String::ucompose( _("remove temporary mountpoint (%1)"), SRC ) ) ) ;
+				OperationDetail( String::ucompose( _("remove temporary mount point (%1)"), SRC ) ) ) ;
 			if ( ! rmdir( SRC .c_str() ) )
 			{
 				operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
@@ -135,7 +135,7 @@
 bool xfs::create( const Partition & new_partition, OperationDetail & operationdetail )
 {
-	//mkfs.xfs will not create filesystem if label is longer than 12 characters, hence truncation.
+	//mkfs.xfs will not create file system if label is longer than 12 characters, hence truncation.
 	Glib::ustring label = new_partition .label ;
 	if( label .length() > 12 )
@@ -227,28 +227,28 @@
 	
-	//create xfs filesystem on destination..
-	/*TO TRANSLATORS: looks like Create new xfs filesystem */ 
+	//create xfs file system on destination..
+	/*TO TRANSLATORS: looks like Create new xfs file system */ 
 	operationdetail .add_child( OperationDetail( 
@@ -227,28 +227,28 @@
 		operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 		
-		//create source mountpoint...
+		//create source mount point...
 		operationdetail .add_child( 
@@ -227,28 +227,28 @@
 			operationdetail .get_last_child() .set_status( STATUS_SUCCES ) ;
 			
-			//create destination mountpoint...
+			//create destination mount point...
 			operationdetail .add_child(
@@ -327,9 +327,9 @@
 				}
 		
-				//remove destination mountpoint..
+				//remove destination mount point..
 				operationdetail .add_child(
@@ -350,9 +350,9 @@
 			}
 			
-			//remove source mountpoint..
+			//remove source mount point..
 			operationdetail .add_child(



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]